aboutsummaryrefslogtreecommitdiffstats
path: root/catalog-be/src/main/java/org/openecomp/sdc/be/components/impl/ProductBusinessLogic.java
diff options
context:
space:
mode:
Diffstat (limited to 'catalog-be/src/main/java/org/openecomp/sdc/be/components/impl/ProductBusinessLogic.java')
-rw-r--r--catalog-be/src/main/java/org/openecomp/sdc/be/components/impl/ProductBusinessLogic.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/catalog-be/src/main/java/org/openecomp/sdc/be/components/impl/ProductBusinessLogic.java b/catalog-be/src/main/java/org/openecomp/sdc/be/components/impl/ProductBusinessLogic.java
index 30a9f799fe..ff532b237d 100644
--- a/catalog-be/src/main/java/org/openecomp/sdc/be/components/impl/ProductBusinessLogic.java
+++ b/catalog-be/src/main/java/org/openecomp/sdc/be/components/impl/ProductBusinessLogic.java
@@ -232,7 +232,7 @@ public class ProductBusinessLogic extends ComponentBusinessLogic {
validateUserExists(userId, "validate Product Name Exists", false);
Either<Boolean, StorageOperationStatus> dataModelResponse = toscaOperationFacade.validateComponentNameUniqueness(productName, null, ComponentTypeEnum.PRODUCT);
// DE242223
- titanDao.commit();
+ janusGraphDao.commit();
if (dataModelResponse.isLeft()) {
Map<String, Boolean> result = new HashMap<>();
@@ -378,7 +378,7 @@ public class ProductBusinessLogic extends ComponentBusinessLogic {
for (Map.Entry<String, Map<String, Set<String>>> entry : nonDuplicatedCategories.entrySet()) {
catExist = false;
CategoryDefinition categoryDefinition = null;
- // over all categories from Titan
+ // over all categories from JanusGraph
List<CategoryDefinition> categoriesList = allProductCategories.left().value();
if (categoriesList != null) {
for (CategoryDefinition catInDb : categoriesList) {
@@ -415,7 +415,7 @@ public class ProductBusinessLogic extends ComponentBusinessLogic {
}
if (!groupExist) {
// error grouping isn't defined
- // in Titan
+ // in JanusGraph
ResponseFormat responseFormat = componentsUtils.getResponseFormat(ActionStatus.INVALID_GROUP_ASSOCIATION, CategoryTypeEnum.GROUPING.getValue(), group);
componentsUtils.auditComponentAdmin(responseFormat, user, product, actionEnum, ComponentTypeEnum.PRODUCT);
return Either.right(responseFormat);
@@ -426,7 +426,7 @@ public class ProductBusinessLogic extends ComponentBusinessLogic {
}
}
if (!subcatExist) {
// error sub category isn't defined in Titan
ResponseFormat responseFormat = componentsUtils.getResponseFormat(ActionStatus.INVALID_GROUP_ASSOCIATION, CategoryTypeEnum.SUBCATEGORY.getValue(), subcat.getKey());
componentsUtils.auditComponentAdmin(responseFormat, user, product, actionEnum, ComponentTypeEnum.PRODUCT);
return Either.right(responseFormat);
@@ -437,7 +437,7 @@ public class ProductBusinessLogic extends ComponentBusinessLogic {
}
}
if (!catExist) {
// error category isn't defined in Titan
ResponseFormat responseFormat = componentsUtils.getResponseFormat(ActionStatus.INVALID_GROUP_ASSOCIATION, CategoryTypeEnum.CATEGORY.getValue(), entry.getKey());
componentsUtils.auditComponentAdmin(responseFormat, user, product, actionEnum, ComponentTypeEnum.PRODUCT);
return Either.right(responseFormat);
@@ -426,7 +426,7 @@ public class ProductBusinessLogic extends ComponentBusinessLogic {
}
if (!subcatExist) {
- // error sub category isn't defined in Titan
+ // error sub category isn't defined in JanusGraph
ResponseFormat responseFormat = componentsUtils.getResponseFormat(ActionStatus.INVALID_GROUP_ASSOCIATION, CategoryTypeEnum.SUBCATEGORY.getValue(), subcat.getKey());
componentsUtils.auditComponentAdmin(responseFormat, user, product, actionEnum, ComponentTypeEnum.PRODUCT);
@@ -437,7 +437,7 @@ public class ProductBusinessLogic extends ComponentBusinessLogic {
}
if (!catExist) {
- // error category isn't defined in Titan
+ // error category isn't defined in JanusGraph
ResponseFormat responseFormat = componentsUtils.getResponseFormat(ActionStatus.INVALID_GROUP_ASSOCIATION, CategoryTypeEnum.CATEGORY.getValue(), entry.getKey());
componentsUtils.auditComponentAdmin(responseFormat, user, product, actionEnum, ComponentTypeEnum.PRODUCT);